==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/NextComponentOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.982Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextComponentOptions")
@software.amazon.jsii.Jsii.Proxy(NextComponentOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NextComponentOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Setup Tailwind as a PostCSS plugin.
     * <p>
     * Default: true
     * <p>
     * @see https://tailwindcss.com/docs/installation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTailwind() {
        return null;
    }

    /**
     * (experimental) Whether to apply options specific for TypeScript Next.js projects.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTypescript() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NextComponentOptions> {
        java.lang.Boolean tailwind;
        java.lang.Boolean typescript;

        /**
         * Sets the value of {@link NextComponentOptions#getTailwind}
         * @param tailwind Setup Tailwind as a PostCSS plugin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(java.lang.Boolean tailwind) {
            this.tailwind = tailwind;
            return this;
        }

        /**
         * Sets the value of {@link NextComponentOptions#getTypescript}
         * @param typescript Whether to apply options specific for TypeScript Next.js projects.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(java.lang.Boolean typescript) {
            this.typescript = typescript;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextComponentOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NextComponentOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextComponentOptions {
        private final java.lang.Boolean tailwind;
        private final java.lang.Boolean typescript;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.tailwind = software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.typescript = software.amazon.jsii.Kernel.get(this, "typescript", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.tailwind = builder.tailwind;
            this.typescript = builder.typescript;
        }

        @Override
        public final java.lang.Boolean getTailwind() {
            return this.tailwind;
        }

        @Override
        public final java.lang.Boolean getTypescript() {
            return this.typescript;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTailwind() != null) {
                data.set("tailwind", om.valueToTree(this.getTailwind()));
            }
            if (this.getTypescript() != null) {
                data.set("typescript", om.valueToTree(this.getTypescript()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.NextComponentOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextComponentOptions.Jsii$Proxy that = (NextComponentOptions.Jsii$Proxy) o;

            if (this.tailwind != null ? !this.tailwind.equals(that.tailwind) : that.tailwind != null) return false;
            return this.typescript != null ? this.typescript.equals(that.typescript) : that.typescript == null;
        }

        @Override
        public final int hashCode() {
            int result = this.tailwind != null ? this.tailwind.hashCode() : 0;
            result = 31 * result + (this.typescript != null ? this.typescript.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/NextComponentOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.656Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextComponentOptions")
@software.amazon.jsii.Jsii.Proxy(NextComponentOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NextComponentOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Setup Tailwind as a PostCSS plugin.
     * <p>
     * Default: true
     * <p>
     * @see <a href="https://tailwindcss.com/docs/installation">https://tailwindcss.com/docs/installation</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTailwind() {
        return null;
    }

    /**
     * (experimental) Whether to apply options specific for TypeScript Next.js projects.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTypescript() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NextComponentOptions> {
        java.lang.Boolean tailwind;
        java.lang.Boolean typescript;

        /**
         * Sets the value of {@link NextComponentOptions#getTailwind}
         * @param tailwind Setup Tailwind as a PostCSS plugin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(java.lang.Boolean tailwind) {
            this.tailwind = tailwind;
            return this;
        }

        /**
         * Sets the value of {@link NextComponentOptions#getTypescript}
         * @param typescript Whether to apply options specific for TypeScript Next.js projects.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(java.lang.Boolean typescript) {
            this.typescript = typescript;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextComponentOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NextComponentOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextComponentOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextComponentOptions {
        private final java.lang.Boolean tailwind;
        private final java.lang.Boolean typescript;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.tailwind = software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.typescript = software.amazon.jsii.Kernel.get(this, "typescript", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.tailwind = builder.tailwind;
            this.typescript = builder.typescript;
        }

        @Override
        public final java.lang.Boolean getTailwind() {
            return this.tailwind;
        }

        @Override
        public final java.lang.Boolean getTypescript() {
            return this.typescript;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTailwind() != null) {
                data.set("tailwind", om.valueToTree(this.getTailwind()));
            }
            if (this.getTypescript() != null) {
                data.set("typescript", om.valueToTree(this.getTypescript()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.NextComponentOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextComponentOptions.Jsii$Proxy that = (NextComponentOptions.Jsii$Proxy) o;

            if (this.tailwind != null ? !this.tailwind.equals(that.tailwind) : that.tailwind != null) return false;
            return this.typescript != null ? this.typescript.equals(that.typescript) : that.typescript == null;
        }

        @Override
        public final int hashCode() {
            int result = this.tailwind != null ? this.tailwind.hashCode() : 0;
            result = 31 * result + (this.typescript != null ? this.typescript.hashCode() : 0);
            return result;
        }
    }
}
